@@ -7,10 +7,13 @@
 #include "hdrcalibrator_debug.h"
 
 #include <KAboutData>
+#include <KConfigGroup>
 #include <KCrash>
 #include <KLocalizedQmlContext>
 #include <KLocalizedString>
+#include <KSharedConfig>
 #include <QGuiApplication>
+#include <QtDBus/QtDBus>
 
 using namespace Qt::StringLiterals;
 
@@ -34,6 +37,18 @@ void HdrCalibrator::applyConfig()
     connect(m_setOp, &KScreen::SetConfigOperation::finished, this, &HdrCalibrator::setOpFinished);
 }
 
+void HdrCalibrator::applyConfigForWindowsApps()
+{
+    auto config = KSharedConfig::openConfig("kwinrc");
+    auto group = config->group("Windows_HDR");
+    group.writeEntry("Reference", sdrBrightness());
+    group.writeEntry("MaxFrameAverage", maxAverageBrightnessOverride());
+    group.writeEntry("MaxLuminance", peakBrightnessOverride());
+    config->sync();
+    QDBusMessage message = QDBusMessage::createSignal("/KWin", "org.kde.KWin", "reloadConfig");
+    QDBusConnection::sessionBus().send(message);
+}
+
 void HdrCalibrator::safeQuit()
 {
     if (m_setOp || m_compressor.isActive()) {
@@ -63,6 +78,11 @@ qreal HdrCalibrator::peakBrightness() const
     return m_output->maxPeakBrightness();
 }
 
+qreal HdrCalibrator::maxAverageBrightness() const
+{
+    return m_output->maxAverageBrightness();
+}
+
 qreal HdrCalibrator::peakBrightnessOverride() const
 {
     return m_output->maxPeakBrightnessOverride().value_or(0);
@@ -73,6 +93,16 @@ void HdrCalibrator::setPeakBrightnessOverride(qreal override)
     m_output->setMaxPeakBrightnessOverride(override);
 }
 
+qreal HdrCalibrator::maxAverageBrightnessOverride() const
+{
+    return m_output->maxAverageBrightnessOverride().value_or(0);
+}
+
+void HdrCalibrator::setMaxAverageBrightnessOverride(qreal override)
+{
+    m_output->setMaxAverageBrightnessOverride(override);
+}
+
 qreal HdrCalibrator::brightness() const
 {
     return m_output->brightness();
@@ -99,6 +129,7 @@ void HdrCalibrator::setOutput(const KScreen::ConfigPtr &config, const KScreen::O
     m_output = output;
     connect(output.get(), &KScreen::Output::brightnessChanged, this, &HdrCalibrator::brightnessChanged);
     connect(output.get(), &KScreen::Output::maxPeakBrightnessOverrideChanged, this, &HdrCalibrator::peakBrightnessOverrideChanged);
+    connect(output.get(), &KScreen::Output::maxAverageBrightnessOverrideChanged, this, &HdrCalibrator::maxAverageBrightnessOverrideChanged);
     connect(output.get(), &KScreen::Output::brightnessChanged, this, &HdrCalibrator::brightnessChanged);
     connect(output.get(), &KScreen::Output::sdrBrightnessChanged, this, &HdrCalibrator::sdrBrightnessChanged);
 }
@@ -123,8 +154,14 @@ int main(int argc, char **argv)
     KAboutData::setApplicationData(aboutData);
     KCrash::initialize();
 
-    // first, get the output
-    // we can't do anything until we have it, so this just blocks
+    // HDR calibration doesn't work properly while night light is enabled -> inhibit it
+    const QString s_serviceName = QStringLiteral("org.kde.KWin.NightLight");
+    const QString s_path = QStringLiteral("/org/kde/KWin/NightLight");
+    const QString s_interface = QStringLiteral("org.kde.KWin.NightLight");
+    const QDBusMessage message = QDBusMessage::createMethodCall(s_serviceName, s_path, s_interface, QStringLiteral("inhibit"));
+    QDBusConnection::sessionBus().asyncCall(message);
+
+    // Get the output. we can't do anything until we have it, so this just blocks
     auto getOp = std::make_unique<KScreen::GetConfigOperation>();
     if (!getOp->exec()) {
         qCWarning(HDRCALIBRATOR) << "failed to get a config!";
