@@ -62,6 +62,7 @@ public:
         BitsPerColorOptionsPreferEfficiencyRole,
         BitsPerColorOptionsPreferAccuracyRole,
         SharpnessRole,
+        AutoBrightnessRole,
     };
     Q_ENUM(OutputRoles)
 
@@ -162,6 +163,7 @@ private:
 
     bool positionable(const Output &output) const;
 
+    std::optional<QList<KScreen::OutputPtr>> possibleReplicationSources(const KScreen::OutputPtr &output) const;
     QStringList replicationSourceModel(const KScreen::OutputPtr &output) const;
     bool setReplicationSourceIndex(int outputIndex, int sourceIndex);
     int replicationSourceIndex(int outputIndex) const;
